@@ -1,5 +1,6 @@
 import logging
 from functools import partial
+from typing import Optional
 
 import numpy as np
 import qcodes as qc
@@ -101,6 +102,9 @@ class Q1Simulator(qc.Instrument):
             self.in0_gain(0)
             self.in1_gain(0)
 
+    def get_idn(self):
+        return dict(vendor='Q1Simulator', model=self._sim_type, serial='', firmware='')
+
     @property
     def instrument_class(self):
         return InstrumentClass.PULSAR
@@ -133,6 +137,12 @@ class Q1Simulator(qc.Instrument):
         seq_nr = int(name[9])
         self.sequencers[seq_nr]._set_legacy(name[11:], value)
 
+    def get_num_system_error(self):
+        return 0
+
+    def get_system_error(self):
+        return '0,"No error"'
+
     def get_system_state(self):
         return SystemState(
             SystemStatus.OKAY,
@@ -143,11 +153,12 @@ class Q1Simulator(qc.Instrument):
         self.armed_seq.add(seq_nr)
         self.sequencers[seq_nr].arm()
 
-    def start_sequencer(self):
-        for seq_nr in self.armed_seq:
+    def start_sequencer(self, sequencer: Optional[int] = None):
+        start_indices = self.armed_seq if sequencer is None else (sequencer,)
+        for seq_nr in start_indices:
             self.sequencers[seq_nr].run()
 
-    def stop_sequencer(self):
+    def stop_sequencer(self, sequencer: Optional[int] = None):
         self.armed_seq = set()
 
     def get_sequencer_state(self, seq_nr, timeout=0):
@@ -159,6 +170,9 @@ class Q1Simulator(qc.Instrument):
     def get_acquisitions(self, seq_nr, timeout=0):
         return self.sequencers[seq_nr].get_acquisition_data()
 
+    def delete_acquisition_data(self, seq_nr, name='', all=False):
+        self.sequencers[seq_nr].delete_acquisition_data(name=name, all=all)
+
     def config_seq(self, seq_nr, name, value):
         self.sequencers[seq_nr].config(name, value)
 
@@ -197,3 +211,4 @@ class Q1Simulator(qc.Instrument):
 
     def print_registers(self, seq_nr, reg_nrs=None):
         self.sequencers[seq_nr].print_registers(reg_nrs)
+
